import sys
sys.path.append('plurk_oauth/')
from PlurkAPI import PlurkAPI
import getopt
import json

def usage():
    print '''Help Information:
    -h: Show help information
    '''

if __name__ == '__main__':
    try:
        opts, args = getopt.getopt(sys.argv[1:], "ho:v", ["help", "output="])
    except getopt.GetoptError, err:
        print str(err) # will print something like "option -a not recognized"
        usage()
        sys.exit(2)
    file = open('API.keys', 'r+')
    data = json.load(file)
    plurk = PlurkAPI(data["CONSUMER_KEY"], data["CONSUMER_SECRET"])
    if data.get('ACCESS_TOKEN'):
        plurk.authorize(data["ACCESS_TOKEN"],data["ACCESS_TOKEN_SECRET"])
    else:
        plurk.authorize()
        data["ACCESS_TOKEN"] = plurk._oauth.oauth_token['oauth_token']
        data["ACCESS_TOKEN_SECRET"] = plurk._oauth.oauth_token['oauth_token_secret']
        json.dump(data,file)

    content = 'Test from Plurk OAuth API'
    if len(sys.argv) > 1:  
        content = sys.argv[1]
    qualifier = 'says'
    if len(sys.argv) > 2:  
        qualifier = sys.argv[2]
    print plurk.callAPI('/APP/Timeline/plurkAdd', {
        'content': content,
        'qualifier': qualifier } )
    



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

config = {
    'description': 'Plurk OAuth API',
    'author': 'Cheng-Lung Sung',
    'url': 'https://github.com/clsung/plurk-oauth',
    'download_url': 'http://pypi.python.org/pypi/plurk-oauth',
    'author_email': 'clsung@gmail.com',
    'version': '0.4.2',
    'install_requires': ['nose', 'oauth2'],
    'packages': ['plurk_oauth'],
    'scripts': ['bin/get_own_profile.py', 'bin/post_to_plurk.py'],
    'name': 'plurk-oauth'
}

setup(**config)
